<TS version="2.1" language="ve">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation type="unfinished">Kha vha puṱedze nga tsha u ḽa u itela u shandula ḓiresi kana ḽebuḽu</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation type="unfinished">Kha vha ite ḓiresi ntswa</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation type="unfinished">&amp;Tshiswa</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation type="unfinished">&amp;Kopa</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation type="unfinished">Vala</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation type="unfinished">Kha vha phumule ḓiresi yo khethiwaho zwa zwino kha mutevhe</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation type="unfinished">Ṅwalani ḓiresi kana ḽebuḽu u itela u setsha</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">Rumelani nnḓa datha kha thebu ya zwino kha faila</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;Tshivhambadzwaseli</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished">&amp;Thutha</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation type="unfinished">Khethani ḓiresi ine na ḓo rumela tshelede ya tsimbi khayo</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation type="unfinished">Khethani ḓiresi ine na ḓo ṱanganedza ngayo tshelede ya tsimbi nga .</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation type="unfinished">Nanga</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation type="unfinished">Hedzi ndi ḓiresi dzaṋu dza Bitcoin dza u rumela mbadelo. Tshifhinga tshoṱhe ṱolani tshelede na ḓiresi ine na ḓo i ṱanganedza musi ni sa athu rumela tshelede ya tsimbi.</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for receiving payments. Use the 'Create new receiving address' button in the receive tab to create new addresses.
Signing is only possible with addresses of the type 'legacy'.</source>
        <translation type="unfinished">Hedzi ndi ḓiresi dzaṋu dza Bitcoin dza u ṱanganedza mbadelo. Shumisani butoni ya 'Sika ḓiresi ntswa ya u ṱanganedza' kha thebu ya u ṱanganedza u sika ḓiresi ntswa.U saina zwi konadzea fhedzi nga ḓiresi dza lushaka lwa 'legacy'.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation type="unfinished">&amp;Khophisa Ḓiresi</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation type="unfinished">Kopa &amp;Lebula</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished">&amp;Dzudzanya</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation type="unfinished">Mutevhe wa Ḓiresi dza u Rumela nnḓa</translation>
    </message>
    <message>
        <source>Comma separated file</source>
        <extracomment>Expanded name of the CSV file format. See: https://en.wikipedia.org/wiki/Comma-separated_values.</extracomment>
        <translation type="unfinished">Faela yo fhandekanywaho nga khoma</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <extracomment>An error message. %1 is a stand-in argument for the name of the file we attempted to save to.</extracomment>
        <translation type="unfinished">Ho vha na vhukhakhi ha u lingedza u vhulunga mutevhe wa ḓiresi kha %1. Ndi khou humbela uri ni lingedze hafhu.</translation>
    </message>
    <message>
        <source>Sending addresses - %1</source>
        <translation type="unfinished">Ḓiresi dza u rumela - %1.</translation>
    </message>
    <message>
        <source>Receiving addresses - %1</source>
        <translation type="unfinished">Ḓiresi dza u ṱanganedza - %1.</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">U rumela nnḓa zwo kundelwa</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">Leibele</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">Ḓiresi</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(a hu na lebula)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation type="unfinished">Nyambedzano ya Mubulo wa Phasiwese</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation type="unfinished">Ṅwalani ḽifurase</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation type="unfinished">Mubulo wa phasiwesi muswa</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation type="unfinished">Dovholola ḽifurase ḽiswa</translation>
    </message>
    <message>
        <source>Show passphrase</source>
        <translation type="unfinished">Sumbedzani phusiphirase</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation type="unfinished">Tshipatshi tsha u ṅwalulula</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation type="unfinished">Mushumo uyu u ṱoḓa passphrase ya tshipatshi tshaṋu u itela u vula tshipatshi.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation type="unfinished">Vulani tshipatshi</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation type="unfinished">Shandukisani mubulo wa phasiwese</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation type="unfinished">Kha vha khwaṱhisedze u ṅwalulula tshipatshi</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
        <translation type="unfinished">Tsevho: Arali na ṅwalulula tshipatshi tshaṋu nahone na xelelwa nga passphrase yaṋu, ni ḓo XELELA BITCOIN DZANU DZOṰHE!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation type="unfinished">Naa ni na vhuṱanzi ha uri ni tama u ṅwalulula tshipatshi tshaṋu?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation type="unfinished">Tshipatshi tsho ṅwaliwa</translation>
    </message>
    <message>
        <source>Enter the new passphrase for the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation type="unfinished">Ṅwalani ḽifurase ḽiswa ḽa tshipatshi. Kha vha shumise ḽifurase ḽa maḽeḓere a fumi kana u fhira, kana maipfi a fusumbe kana u fhira</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase for the wallet.</source>
        <translation type="unfinished">Ṅwalani ṱhalutshedzo ya kale na ṱhalutshedzo ntswa ya tshipatshi.</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation type="unfinished">Bvelaphanḓa</translation>
    </message>
    <message>
        <source>Back</source>
        <translation type="unfinished">Murahu</translation>
    </message>
    <message>
        <source>Remember that encrypting your wallet cannot fully protect your bitcoins from being stolen by malware infecting your computer.</source>
        <translation type="unfinished">Humbulani uri u ṅwalulula tshipatshi tshaṋu a zwi nga koni u tsireledza nga vhuḓalo bitcoins dzaṋu kha u tswiwa nga malware ine ya kavhila khomphyutha yaṋu.</translation>
    </message>
    <message>
        <source>Wallet to be encrypted</source>
        <translation type="unfinished">Tshipatshi tshi do ṅwaliwa</translation>
    </message>
    <message>
        <source>Your wallet is about to be encrypted. </source>
        <translation type="unfinished">Tshipatshi tshanu tshi tsini na u ṅwaliwa.</translation>
    </message>
    <message>
        <source>Your wallet is now encrypted. </source>
        <translation type="unfinished">Tshipatshi tshanu tsho no ṅwaliwa.</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation type="unfinished">ZWA NDEME: Backup dziṅwe na dziṅwe dza kale dze na dzi ita dza faila ya tshipatshi tshaṋu dzi fanela u dzhielwa vhudzulo nga faila ya tshipatshi ntswa yo bveledzwaho, yo ṅwaliwaho. Nga ṅwambo wa tsireledzo, u vhulunga ha kale ha faila ya tshipatshi tshi songo ṅwaliwaho zwi ḓo vha zwi si na mushumo nga u ṱavhanya musi ni tshi thoma u shumisa tshipatshi tshiswa tsho ṅwaliwaho.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation type="unfinished">U ṅwalulula tshipatshi zwo kundelwa</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation type="unfinished">U ṅwalulula tshipatshi zwo kundelwa nga mulandu wa vhukhakhi ha nga ngomu. Tshipatshi tshanu tsho vha tshi songo ṅwaliwa.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation type="unfinished">Mafhungo a u ṋekedza a a tendelani.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation type="unfinished">U vula tshipatshi zwo kundelwa</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation type="unfinished">Phasiphrase yo dzheniswaho ya u bvisa tshipatshi yo vha yo khakhea.</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption is incorrect. It contains a null character (ie - a zero byte). If the passphrase was set with a version of this software prior to 25.0, please try again with only the characters up to — but not including — the first null character. If this is successful, please set a new passphrase to avoid this issue in the future.</source>
        <translation type="unfinished">Phasiphrase yo dzheniswaho ya u bvisa tshipatshi a yo ngo tea. I na tshiga tsha null (ndi uri - byte ya zero). Arali mubulo wa u dzhena wo vhewa na mbekanyamushumo ya sofuthiwee iyi phanḓa ha 25.0, kha vha lingedze hafhu nga maḽeḓere fhedzi u swika kha — fhedzi vha sa kateli — maḽeḓere a u thoma a si na mushumo. Arali zwo bvelela, kha vha vhee passphrase ntswa u itela u iledza thaidzo iyi tshifhingani tshi ḓaho.</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation type="unfinished">Phasiphrase ya tshipatshi yo shandukiswa nga nḓila yo bvelelaho.</translation>
    </message>
    <message>
        <source>Passphrase change failed</source>
        <translation type="unfinished">Tshanduko ya phasiphrase yo kundelwa</translation>
    </message>
    <message>
        <source>The old passphrase entered for the wallet decryption is incorrect. It contains a null character (ie - a zero byte). If the passphrase was set with a version of this software prior to 25.0, please try again with only the characters up to — but not including — the first null character.</source>
        <translation type="unfinished">Phasiphrase ya kale yo dzheniswaho ya u bvisa tshipatshi a yo ngo tea. I na tshiga tsha null (ndi uri - byte ya zero). Arali mubulo wa u dzhena wo vhewa na mbekanyamushumo ya sofuthiwee iyi phanḓa ha 25.0, kha vha lingedze hafhu nga maḽeḓere fhedzi u swika kha — fhedzi vha sa kateli — maḽeḓere a u thoma a si na mushumo.</translation>
    </message>
    </context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>IP/Netmask</source>
        <translation type="unfinished">IP/Masiki</translation>
    </message>
    <message>
        <source>Banned Until</source>
        <translation type="unfinished">Yo iledzwa u swika</translation>
    </message>
</context>
<context>
    <name>BitcoinApplication</name>
    <message>
        <source>Settings file %1 might be corrupt or invalid.</source>
        <translation type="unfinished">
Faela ya zwishumiswa %1 i nga vha yo tshinyala kana i sa shumi.</translation>
    </message>
    <message>
        <source>Runaway exception</source>
        <translation type="unfinished">U shavha nga nnḓa ha</translation>
    </message>
    <message>
        <source>A fatal error occurred. %1 can no longer continue safely and will quit.</source>
        <translation type="unfinished">Ho itea vhukhakhi vhu vhulayaho. %1 a i tsha kona u bvela phanḓa yo tsireledzea nahone i ḓo litsha.</translation>
    </message>
    <message>
        <source>Internal error</source>
        <translation type="unfinished">Vhukhakhi ha nga ngomu</translation>
    </message>
    <message>
        <source>An internal error occurred. %1 will attempt to continue safely. This is an unexpected bug which can be reported as described below.</source>
        <translation type="unfinished">Ho itea vhukhakhi ha nga ngomu. %1 i do lingedza u isa phanda yo tsireledzea. Heyi ndi bug i songo lavhelelwaho ine ya nga vhigwa sa zwe zwa ṱalutshedzwa afho fhasi.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Do you want to reset settings to default values, or to abort without making changes?</source>
        <extracomment>Explanatory text shown on startup when the settings file cannot be read. Prompts user to make a choice between resetting or aborting.</extracomment>
        <translation type="unfinished">Naa ni ṱoḓa u vhuedzedza zwishumiswa kha ndeme dza kale, kana u litsha ni sa iti tshanduko?</translation>
    </message>
    <message>
        <source>A fatal error occurred. Check that settings file is writable, or try running with -nosettings.</source>
        <extracomment>Explanatory text shown on startup when the settings file could not be written. Prompts user to check that we have the ability to write to the file. Explains that the user has the option of running without a settings file.</extracomment>
        <translation type="unfinished">Ho itea vhukhakhi vhu vhulayaho. Sedzani uri faila ya zwishumiswa i a ṅwaliwa, kana ni lingedze u shuma na -nosettings.</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation type="unfinished">Vhukhakhi: %1.</translation>
    </message>
    <message>
        <source>%1 didn't yet exit safely…</source>
        <translation type="unfinished">%1 a i athu bva yo tsireledzea...</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>&amp;Overview</source>
        <translation type="unfinished">&amp;Tshiṱolisiso</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation type="unfinished">Sumbedzani ṱhalutshedzo yo angaredzaho ya tshipatshi</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation type="unfinished">&amp;Tshingiselano</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation type="unfinished">Kha vha sedze ḓivhazwakale ya thengiselano</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation type="unfinished">U bva</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation type="unfinished">Litshani khumbelo</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation type="unfinished">&amp;Nga ha %1.</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation type="unfinished">Sumbedza mafhungo nga ha %1.</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation type="unfinished">Nga ha &amp;Qt</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation type="unfinished">Sumbedza mafhungo nga ha Qt .</translation>
    </message>
    <message>
        <source>Modify configuration options for %1</source>
        <translation type="unfinished">Kha vha shandukise khetho dza nzudzanyo dza %1.</translation>
    </message>
    <message>
        <source>Create a new wallet</source>
        <translation type="unfinished">Kha vha ite tshipatshi tshiswa</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation type="unfinished">&amp;Fhungudza</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">Tshipatshi:</translation>
    </message>
    <message>
        <source>Network activity disabled.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">Mushumo wa nethiweke wo thivhelwa.</translation>
    </message>
    <message>
        <source>Proxy is &lt;b&gt;enabled&lt;/b&gt;: %1</source>
        <translation type="unfinished">Proxy yo tendelwa: %1.</translation>
    </message>
    <message>
        <source>Send coins to a Bitcoin address</source>
        <translation type="unfinished">Rumelani tshelede ya tsimbi kha ḓiresi ya Bitcoin .</translation>
    </message>
    <message>
        <source>Backup wallet to another location</source>
        <translation type="unfinished">Backup wallet kha inwe fhethu</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation type="unfinished">Shandukisani ḽifurase ḽo shumiswaho kha u ṅwalulula tshipatshi</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation type="unfinished">&amp;Rumela</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation type="unfinished">&amp;Ṱanganedza</translation>
    </message>
    <message>
        <source>&amp;Options…</source>
        <translation type="unfinished">&amp;Khetho...</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet…</source>
        <translation type="unfinished">&amp;Kha vha ṅwale Tshipatshi...</translation>
    </message>
    <message>
        <source>Encrypt the private keys that belong to your wallet</source>
        <translation type="unfinished">Kha vha ṅwalulule khii dza phuraivethe dzine dza vha dza tshipatshi tshavho</translation>
    </message>
    <message>
        <source>&amp;Backup Wallet…</source>
        <translation type="unfinished">&amp;Tshipatshi tsha u vhulunga...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase…</source>
        <translation type="unfinished">&amp;Shandukisa Mubulo wa Phasi...</translation>
    </message>
    <message>
        <source>Sign &amp;message…</source>
        <translation type="unfinished">Saina &amp;mulaedza...</translation>
    </message>
    <message>
        <source>Sign messages with your Bitcoin addresses to prove you own them</source>
        <translation type="unfinished">Saini milaedza nga ḓiresi dzaṋu dza Bitcoin u sumbedza uri ndi vhaṋe vhayo .</translation>
    </message>
    <message>
        <source>&amp;Verify message…</source>
        <translation type="unfinished">&amp;Kha vha khwaṱhisedze mulaedza...</translation>
    </message>
    <message>
        <source>Verify messages to ensure they were signed with specified Bitcoin addresses</source>
        <translation type="unfinished">Kha vha khwaṱhisedze milaedza u vhona uri yo sainiwa nga ḓiresi dzo bulwaho dza Bitcoin </translation>
    </message>
    <message>
        <source>&amp;Load PSBT from file…</source>
        <translation type="unfinished">&amp;Load PSBT ubva kha faila...</translation>
    </message>
    <message>
        <source>Open &amp;URI…</source>
        <translation type="unfinished">Vula &amp;URI...</translation>
    </message>
    <message>
        <source>Close Wallet…</source>
        <translation type="unfinished">Vhalani Tshipatshi...</translation>
    </message>
    <message>
        <source>Create Wallet…</source>
        <translation type="unfinished">Kha vha sike Tshipatshi...</translation>
    </message>
    <message>
        <source>Close All Wallets…</source>
        <translation type="unfinished">Vhalani zwipatshi zwothe...</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="unfinished">&amp;Faila</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation type="unfinished">&amp;Zwishumiswa</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished">&amp;Thusa</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation type="unfinished">Bara ya zwishumiswa zwa thebu</translation>
    </message>
    <message>
        <source>Syncing Headers (%1%)…</source>
        <translation type="unfinished">109
U ṱanganya ṱhoho (%1%)...</translation>
    </message>
    <message>
        <source>Synchronizing with network…</source>
        <translation type="unfinished">U ṱanganya na nethiweke...</translation>
    </message>
    <message>
        <source>Indexing blocks on disk…</source>
        <translation type="unfinished">U indexa dzibuloko kha disiki...</translation>
    </message>
    <message>
        <source>Processing blocks on disk…</source>
        <translation type="unfinished">U phurosesa dzibuloko kha disiki...</translation>
    </message>
    <message>
        <source>Connecting to peers…</source>
        <translation type="unfinished">U ṱumana na thangana dza murole...</translation>
    </message>
    <message>
        <source>Request payments (generates QR codes and bitcoin: URIs)</source>
        <translation type="unfinished">Humbelani mbadelo (u bveledza khoudu dza QR na bitcoin: URI)</translation>
    </message>
    <message>
        <source>Show the list of used sending addresses and labels</source>
        <translation type="unfinished">Sumbedzani mutevhe wa ḓiresi dza u rumela dzo shumiswaho na zwiga</translation>
    </message>
    <message>
        <source>Show the list of used receiving addresses and labels</source>
        <translation type="unfinished">Sumbedzani mutevhe wa ḓiresi dza u ṱanganedza dzo shumiswaho na zwiga</translation>
    </message>
    <message>
        <source>&amp;Command-line options</source>
        <translation type="unfinished">&amp;Khetho dza mutevhe wa ndaela</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Bitcoin network.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation type="unfinished">Vhukhakhi: %1.</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(a hu na lebula)</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of space available</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(sufficient to restore backups %n day(s) old)</source>
        <extracomment>Explanatory text on the capability of the current prune target.</extracomment>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Continue</source>
        <translation type="unfinished">Bvelaphanḓa</translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>Address</source>
        <extracomment>Title of Peers Table column which contains the IP/Onion/I2P address of the connected peer.</extracomment>
        <translation type="unfinished">Ḓiresi</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">Tshipatshi:</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">Leibele</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(a hu na lebula)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message numerus="yes">
        <source>Estimated to begin confirmation within %n block(s).</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(a hu na lebula)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation type="unfinished">Tshivhalo:</translation>
    </message>
    <message>
        <source>Choose previously used address</source>
        <translation type="unfinished">Khethani ḓiresi ye ya shumiswa kale</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Choose previously used address</source>
        <translation type="unfinished">Khethani ḓiresi ye ya shumiswa kale</translation>
    </message>
    </context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">Leibele</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(a hu na lebula)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Comma separated file</source>
        <extracomment>Expanded name of the CSV file format. See: https://en.wikipedia.org/wiki/Comma-separated_values.</extracomment>
        <translation type="unfinished">Faela yo fhandekanywaho nga khoma</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">Leibele</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">Ḓiresi</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">U rumela nnḓa zwo kundelwa</translation>
    </message>
    </context>
<context>
    <name>WalletFrame</name>
    <message>
        <source>Create a new wallet</source>
        <translation type="unfinished">Kha vha ite tshipatshi tshiswa</translation>
    </message>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;Tshivhambadzwaseli</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">Rumelani nnḓa datha kha thebu ya zwino kha faila</translation>
    </message>
    </context>
</TS>